OC.L10N.register(
    "gallery",
    {
    "Configuration error" : "Konfiguratiouns Feeler",
    "Error loading slideshow template" : "Feeler beim Luede vun der Virlag fir d'Diashow",
    "Next" : "Weider",
    "Play" : "Ofspillen",
    "Pause" : "Paus",
    "Previous" : "Zeréck",
    "Close" : "Zoumaachen",
    "Download" : "Eroflueden",
    "Delete" : "Läschen",
    "Share" : "Deelen",
    "\"{name}\" is an invalid file name." : "\"{Numm}\" ass een ongültegen Numm fir e Fichier.",
    "File name cannot be empty." : "Den Numm vum Fichier kann net eidel sinn.",
    "Upload" : "Eroplueden",
    "Error" : "Feeler",
    "Error while sharing" : "Feeler beim Deelen",
    "Error while unsharing" : "Feeler beim Annuléiere vum Deelen",
    "Error while changing permissions" : "Feeler beim Ännere vun de Rechter",
    "Shared with you and the group {group} by {owner}" : "Gedeelt mat dir an der Grupp {group} vum {owner}",
    "Shared with you by {owner}" : "Gedeelt mat dir vum {owner}",
    "Share with users or groups …" : "Mat Benotzer oder Gruppen deelen ...",
    "Share with users, groups or remote users …" : "Mat Benotzer, Gruppen oder net präsente Benotzer deelen ...",
    "Share link" : "Link deelen",
    "The public link will expire no later than {days} days after it is created" : "Den ëffentleche Link wäert net méi spéit wéi {Deeg} Deeg nodeems et erstallt gouf verfalen ",
    "Link" : "Link",
    "Password protect" : "Passwuertgeschützt",
    "Password" : "Passwuert",
    "Choose a password for the public link" : "Wiel e Passwuert fir den ëffentleche Link aus",
    "Allow editing" : "Beaarbechten erlaben",
    "Email link to person" : "Link enger Persoun mailen",
    "Send" : "Schécken",
    "Set expiration date" : "Verfallsdatum setzen",
    "Expiration" : "Leeft of",
    "Expiration date" : "Verfallsdatum",
    "Adding user..." : "Benotzer derbäi fügen",
    "group" : "Grupp",
    "remote" : "Op Distanz",
    "Resharing is not allowed" : "Weiderdeelen ass net erlaabt",
    "Unshare" : "Net méi deelen",
    "notify by email" : "via e-mail Bescheed ginn",
    "can share" : "kann deelen",
    "can edit" : "kann änneren",
    "access control" : "Zougrëffskontroll",
    "create" : "erstellen",
    "change" : "änneren",
    "delete" : "läschen",
    "Password protected" : "Passwuertgeschützt",
    "Error unsetting expiration date" : "Feeler beim Läsche vum Verfallsdatum",
    "Error setting expiration date" : "Feeler beim Setze vum Verfallsdatum",
    "Email sent" : "Email geschéckt",
    "Warning" : "Warnung",
    "The password is wrong. Try again." : "Den Passwuert ass incorrect. Probeier ed nach eng keier.",
    "Cancel upload" : "Eroplueden ofbriechen",
    "New" : "Nei"
},
"nplurals=2; plural=(n != 1);");
